/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: FontBaseBadTestCase.java 752153 2009-03-10 16:16:31Z jeremias $ */

package org.apache.fop.config;

/*
 * This font base does not exist and a relative font path is used.
 */
public class FontBaseBadTestCase extends BaseDestructiveUserConfigTestCase {

    public FontBaseBadTestCase(String name) {
        super(name);
    }

    /** {@inheritDoc} */
    public String getUserConfigFilename() {
        return "test_fontbase_bad.xconf";
    }
}
